@@ -563,8 +563,11 @@ class FitsViewerApp(QMainWindow, fitsViewerGui.Ui_MainWindow):
 					# print (header_linenum, file_line)
 					if file_line.startswith("Frame"):
 						break
+					if file_line.startswith("Time"):
+						break
 					if file_line[0].isdigit():
 						header_linenum -= 1
+						break
 			
 			# check for missing header line
 			# print "header_linenum:", header_linenum
@@ -578,14 +581,21 @@ class FitsViewerApp(QMainWindow, fitsViewerGui.Ui_MainWindow):
 				)
 			# imgscan_num_rows = len(imgscan_data)
 
+			column_map = dict({"PNG Image filename": "Filename"})
+			imgscan_data.rename(columns=column_map, inplace=True)
+
 			self.data_pathnames = ["{0:s}/WinView CCD/{1:s}.fits".format(
 				data_path,
 				filename,
-				) for filename in imgscan_data['PNG Image filename'] ]
+				) for filename in imgscan_data["Filename"] ]
 			
 			if (self.data_frame_num > len(self.data_pathnames) ):
 				# self.data_frame_num = len(self.data_pathnames)
 				data_frame_num = len(self.data_pathnames)
+
+			if (len(self.data_pathnames) > 0):
+				# self.data_frame_num = 1
+				data_frame_num = 1
 		
 		else:
 			
