@@ -473,12 +473,10 @@ def get_config():
     # _version.py
     cfg = VersioneerConfig()
     cfg.VCS = "git"
-    # cfg.style = "pep440-micro"
-    # cfg.style = "pep440-develop"
-    cfg.style = "pep440-auto"
-    cfg.tag_prefix = ""
-    cfg.parentdir_prefix = ""
-    cfg.versionfile_source = "als/liam/_version.py"
+    cfg.style = "%(STYLE)s"
+    cfg.tag_prefix = "%(TAG_PREFIX)s"
+    cfg.parentdir_prefix = "%(PARENTDIR_PREFIX)s"
+    cfg.versionfile_source = "%(VERSIONFILE_SOURCE)s"
     cfg.verbose = False
     return cfg
 
@@ -734,7 +732,7 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
             history_search_args = ["--ancestry-path", "--first-parent"]
         distance_to_tag, rc = run_command(
             GITS, ["rev-list", "--count",] + history_search_args +
-                  ["%s..HEAD" % pieces["closest-tag"] ], cwd=root)
+                  ["%%s..HEAD" % pieces["closest-tag"] ], cwd=root)
         pieces["distance"] = int(distance_to_tag)
 
         # commit: short hex revision ID
@@ -754,7 +752,7 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
         GITS, ["merge-base", "master", "HEAD", "-a"], cwd=root)
     distance_to_master, rc = run_command(
         GITS, ["rev-list", "--count", "--ancestry-path",
-        "%s..HEAD" % merge_base_master], cwd=root)
+        "%%s..HEAD" %% merge_base_master], cwd=root)
     pieces["distance-to-master"] = int(distance_to_master)
 
     ##################################################
@@ -763,7 +761,7 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
         # TAG exists
         master_to_tag, rc = run_command(
             GITS, ["rev-list", "--count", "--ancestry-path", "--first-parent",
-                   "%s..%s" % (pieces["closest-tag"], merge_base_master) ],
+                   "%%s..%%s" % (pieces["closest-tag"], merge_base_master) ],
             cwd=root)
         pieces["master-to-tag"] = int(master_to_tag)
     else:
@@ -781,7 +779,7 @@ def git_pieces_from_vcs(tag_prefix, root, verbose, run_command=run_command):
             GITS, ["merge-base", "develop", "HEAD", "-a"], cwd=root)
         distance_to_develop, rc = run_command(
             GITS, ["rev-list", "--count", "--ancestry-path",
-            "%s..HEAD" % merge_base_develop], cwd=root)
+            "%%s..HEAD" %% merge_base_develop], cwd=root)
         pieces["develop"] = branch_develop
         pieces["distance-to-develop"] = int(distance_to_develop)
 
@@ -884,7 +882,7 @@ def render_pep440_old(pieces):
                 rendered += ".dev0"
     else:
         # exception #1
-        rendered = "0.post%d" % pieces["distance"]
+        rendered = "0.post%%d" %% pieces["distance"]
         if pieces["dirty"]:
             rendered += ".dev0"
     return rendered
@@ -900,14 +898,14 @@ def render_pep440_micro(pieces):
     """
     if pieces["closest-tag"]:
         rendered = pieces["closest-tag"]
-        rendered += ".%d" % pieces["distance"]
+        rendered += ".%%d" %% pieces["distance"]
         if pieces["dirty"]:
             rendered += plus_or_dot(pieces)
-            rendered += "g%s" % pieces["short"]
+            rendered += "g%%s" %% pieces["short"]
             rendered += ".dirty"
     else:
         # exception #1
-        rendered = "0+untagged.%d.g%s" % (pieces["distance"],
+        rendered = "0+untagged.%%d.g%%s" %% (pieces["distance"],
                                           pieces["short"])
         if pieces["dirty"]:
             rendered += ".dirty"
@@ -931,14 +929,14 @@ def render_pep440_develop(pieces):
         # distance_merge_to_tag = (pieces["distance"] - distance_to_merge)
         distance_merge_to_tag = pieces["master-to-tag"]
         if (distance_merge_to_tag > 0):
-            rendered += ".%d" % distance_merge_to_tag
-        rendered += ".post.dev%d" % distance_to_merge
+            rendered += ".%%d" %% distance_merge_to_tag
+        rendered += ".post.dev%%d" %% distance_to_merge
     else:
         # exception #1
-        rendered = "0.post.dev%d" % (pieces["distance"] - 1)
+        rendered = "0.post.dev%%d" %% (pieces["distance"] - 1)
     if pieces["dirty"]:
         rendered += plus_or_dot(pieces)
-        rendered += "g%s" % pieces["short"]
+        rendered += "g%%s" %% pieces["short"]
         rendered += ".dirty"
     return rendered
 
@@ -963,17 +961,17 @@ def render_pep440_feature(pieces):
         distance_merge_to_tag = pieces["master-to-tag"]
         distance_dev_to_merge = (distance_to_merge - distance_to_develop)
         if (distance_merge_to_tag > 0):
-            rendered += ".%d" % distance_merge_to_tag
-        rendered += ".post.dev%d" % distance_dev_to_merge
+            rendered += ".%%d" %% distance_merge_to_tag
+        rendered += ".post.dev%%d" %% distance_dev_to_merge
         rendered += plus_or_dot(pieces)
-        rendered += "g%s" % pieces["short"]
-        rendered += ".%s" % pieces["branch"]
-        rendered += ".%d" % distance_to_develop
+        rendered += "g%%s" %% pieces["short"]
+        rendered += ".%%s" %% pieces["branch"]
+        rendered += ".%%d" %% distance_to_develop
     else:
         # exception #1
-        rendered = "0.post.dev%d" % (pieces["distance"] - 1)
+        rendered = "0.post.dev%%d" %% (pieces["distance"] - 1)
         rendered += plus_or_dot(pieces)
-        rendered += "g%s" % pieces["short"]
+        rendered += "g%%s" %% pieces["short"]
     if pieces["dirty"]:
         rendered += ".dirty"
     return rendered
